osl_core.h: Replace static inline by _static_inline_.
[paraslash.git] / recv.h
diff --git a/recv.h b/recv.h
index e1ef4e21b8583059bd79e30d4b8d5faef1b30430..ab9bc499371dbb1b9b298428dd8a9941bddf7a11 100644 (file)
--- a/recv.h
+++ b/recv.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2005-2008 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -18,10 +18,10 @@ struct receiver_node {
        size_t loaded;
        /** receiver-specific data */
        void *private_data;
-       /** set to 1 if end of file is reached */
-       int eof;
-       /** pointer to the eof member of the consumer */
-       int *output_eof;
+       /** Set to non-zero error value on errors or on end of file. */
+       int error;
+       /** Pointer to the error member of the consumer. */
+       int *output_error;
        /** pointer to the configuration data for this instance */
        void *conf;
        /** the task associated with this instance */